@@ -12,11 +12,11 @@ import pandas as pd
 from gymnasium.core import RenderFrame, ObsType
 from gymnasium.spaces import Discrete, Box
 
-from akademy.common.utils import format_float
+from akademy.common.utils import format_float, make_ohlcv_from_df_row
 from akademy.models.base_models.trade_env_base import TradeEnvBase
 from akademy.models.trade import Trade
 from akademy.models.trade_action import TradeAction
-from akademy.common.utils import minmax_normalize
+from akademy.models import OHLCV
 
 
 class TradeEnv(TradeEnvBase):
@@ -27,7 +27,7 @@ class TradeEnv(TradeEnvBase):
             asset: str,
             starting_cash: float = 100000,
             pct_based_rewards: bool = True,
-            fractional: bool = False,
+            fractional: bool = False
     ):
         """
         Trading Environment in which simulated trading can occur. Data should
@@ -199,20 +199,21 @@ class TradeEnv(TradeEnvBase):
             done = True
         return done
 
-    def _make_observation(self) -> np.ndarray:
+    def _make_observation(self) -> List[OHLCV]:
         """
-        Fills the observation window up with new state information.
-        Note:
-            normalizes observation data to range of (0, 1) on a per-window basis
+        Creates a collection of OHLCV objects representing a slice of the 
+        current data in the range [i-window - i+1] such that the current
+        period (i) is available with the (window) many previous observations as
+        well. 
+        Note: requires manual implementation of e.g. *not* exposing the OHLCV
+            of the last period to an agent.
         Returns:
-            the current NP array.
+            A list of OHLCV objects for each row in the next observation where
+            the last row is the most recent observation (rows[-1])
         """
-        # -4 cuts off the High, Low, Close and Volume of the last period
-        # leaving only the "open" price known to an observer.
-        raw = self.data.iloc[self.i - self.window: self.i + 1].to_numpy().flatten()[:-4]
-
-        # normalize all observations to [0, 1]
-        return minmax_normalize(data=raw)
+        data = [make_ohlcv_from_df_row(row) for row in
+                self.data.iloc[self.i - self.window: self.i + 1].iterrows()]
+        return data
 
     def _sample_price(self) -> float:
         """
@@ -268,7 +269,7 @@ class TradeEnv(TradeEnvBase):
             price=_price,
             qty=_qty,
             date=self.data.index[self.i].to_pydatetime(),
-            side=TradeAction.BUY.value
+            side=TradeAction.BUY.value  # noqa: it's an int
         )
         logging.debug(f"BUY Action: {report}")
 
@@ -291,13 +292,13 @@ class TradeEnv(TradeEnvBase):
             price=_price,
             qty=_qty,
             date=self.data.index[self.i].to_pydatetime(),
-            side=TradeAction.SELL.value
+            side=TradeAction.SELL.value # noqa: it's an int
         )
         logging.debug(f'SELL: {report}')
 
     def _hold(self):
         """
-        For book-keeping purposes, to track the total number of
+        For bookkeeping purposes, to track the total number of
         actions. Hold actions don't really do anything that would
         need a record, in the Buy/Sell context.
         """
@@ -308,24 +309,24 @@ class TradeEnv(TradeEnvBase):
             price=_price,
             qty=self.qty,
             date=self.data.index[self.i].to_pydatetime(),
-            side=TradeAction.HOLD.value
+            side=TradeAction.HOLD.value # noqa: it's an int
         )
         logging.debug(f'HOLD: {report}')
 
-    def _take_action(self, action: int):
+    def _take_action(self, action: TradeAction):
         """Applies an action to the environment"""
-        if action == TradeAction.BUY.value:
+        if action == TradeAction.BUY:
             return self._buy()
-        elif action == TradeAction.SELL.value:
+        elif action == TradeAction.SELL:
             return self._sell()
-        elif action == TradeAction.HOLD.value:
+        elif action == TradeAction.HOLD:
             return self._hold()
 
         # shouldn't ever reach this
         else:
             raise Exception(f"Invalid Action: {action}")
 
-    def step(self, action: int) -> Tuple[np.array, float, bool, bool, dict, bool]:
+    def step(self, action: TradeAction) -> Tuple[List[OHLCV], float, bool, bool, dict, bool]:
         """
         Applies an action to the current environment and returns an observation
         of the resulting state.
